@@ -383,7 +383,7 @@ class ReservationSync:
             linkedReservation=record.get('linkedReservation'),
             guestInfo=self._get_guest_info(record),
             eCertificates=record.get('eCertificates'),
-            callHistory=record.get('callHistory'),
+            historyEvents=record.get('callHistory'),
             cancellation=record.get('cancellation'),
             comments=record.get('comments'),
             policies=record.get('reservationPolicies'),
@@ -391,6 +391,7 @@ class ReservationSync:
             preferences=record.get('preferenceCollection'),
             memberships=record.get('reservationMemberships'),
             packages=record.get('reservationPackages'),
+            auraRecordUpdatedOn=str(datetime.now())
         )
 
         if record.get('folioInformation'):
