@@ -198,6 +198,11 @@ class PropertyAccountsReceivableDetails(BaseModel):
     permanent: bool
 
 
+class PropertyFrontOfficeStats(BaseModel):
+    code: str
+    value: int
+
+
 class Property(BaseModel):
     id: str
     name: str = ''
